@@ -47,11 +47,11 @@ class StatsdServer(DatagramProtocol):
         elif len(met_split) == 3:
             event, event_type, sampling = met_split
         else:
-            raise ValueError('Ivalid number of "|"s, found %d'
+            raise ValueError('Invalid number of "|"s, found %d'
                 % (len(met_split)+1))
         sampling = float(sampling[1:])
         event_name, event_str_val = event.split(':')
-        event_val = int(event_str_val)
+        event_val = float(event_str_val)
         self.type_handlers[event_type](event_name, event_type,
             event_val, sampling)
 
